Builds the encoder and predictor modules for one OmicsTweezer architecture. The encoder contains two fully connected blocks, and the predictor contains two fully connected blocks followed by a linear output layer and softmax.
Builds the encoder and predictor modules for one OmicsTweezer architecture. The encoder contains two fully connected blocks, and the predictor contains two fully connected blocks followed by a linear output layer and softmax.