Internal helper that creates an independent copy of a trained TAPE model by copying encoder and decoder state dictionaries in memory.
Internal helper that creates an independent copy of a trained TAPE model by copying encoder and decoder state dictionaries in memory.